@@ -1,5 +1,6 @@
 import random
 import hashlib
+import datetime
 from django.db import models
 from django.contrib.auth.models import User
 
@@ -21,3 +22,11 @@ class CallbackMapManager(models.Manager):
     def all_live_callbacks(self):
         query = Q(is_active=True) & Q(is_error=False)
         return self.get_query_set().filter(query)
+
+    def all_expired_callbacks(self, days=7, delete_errors=False):
+        use_date = datetime.date.today() - datetime.timedelta(days=days)
+        query = Q(is_active=False) 
+        if not delete_errors:
+            query &= Q(is_error=False)
+        query &= Q(updated_on__lte=use_date)
+        return self.get_query_set().filter(query)
